**To update a primary email address**

The following ``update-primary-email-address`` command updates the primary email address of the specified entity (user, group, or resource). ::

    aws workmail update-primary-email-address \
        --organization-id m-d281d0a2fd824be5b6cd3d3ce909fd27 \
        --entity-id S-1-1-11-1111111111-2222222222-3333333333-3333 \
        --email exampleUser2@site.awsapps.com

This command produces no output.
